pub struct WithdrawOrder {
pub time_lock: TimeLock,
pub protocol_id: ProtocolId,
pub asset_id: u16,
pub amount_base_units: u64,
pub reduce_only: bool,
pub destination: Pubkey,
}Expand description
Time locked order for withdrawing funds from a vault
Fields
time_lock: TimeLockprotocol_id: ProtocolIdasset_id: u16amount_base_units: u64reduce_only: booldestination: PubkeyTrait Implementations
Sourceimpl AccountDeserialize for WithdrawOrder
impl AccountDeserialize for WithdrawOrder
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for WithdrawOrder
impl AccountSerialize for WithdrawOrder
Sourceimpl BorshDeserialize for WithdrawOrder
impl BorshDeserialize for WithdrawOrder
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for WithdrawOrder
impl BorshSerialize for WithdrawOrder
Sourceimpl Clone for WithdrawOrder
impl Clone for WithdrawOrder
Sourcefn clone(&self) -> WithdrawOrder
fn clone(&self) -> WithdrawOrder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WithdrawOrder
impl Debug for WithdrawOrder
Sourceimpl Discriminator for WithdrawOrder
impl Discriminator for WithdrawOrder
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for WithdrawOrder