Module types

Module types 

Program type definitions.

Note that account and event type definitions are not included in this module, as they have their own dedicated modules.

Structs

FeeStructure
FeeTier
OracleGuardRails
OrderFillerRewardStructure
PriceDivergenceGuardRails
PriceFeedMessage
TimeLock
Time lock used to prevent an order being executed before the release_slot
ValidityGuardRails

Enums

ProtocolId
VerificationLevel
Pyth price updates are bridged to all blockchains via Wormhole. Using the price updates on another chain requires verifying the signatures of the Wormhole guardians. The usual process is to check the signatures for two thirds of the total number of guardians, but this can be cumbersome on Solana because of the transaction size limits, so we also allow for partial verification.