VerificationLevel

Enum VerificationLevel 

pub enum VerificationLevel {
    Partial {
        num_signatures: u8,
    },
    Full,
}
Pyth price updates are bridged to all blockchains via Wormhole. Using the price updates on another chain requires verifying the signatures of the Wormhole guardians. The usual process is to check the signatures for two thirds of the total number of guardians, but this can be cumbersome on Solana because of the transaction size limits, so we also allow for partial verification.

This enum represents how much a price update has been verified:

  • If Full, we have verified the signatures for two thirds of the current guardians.
  • If Partial, only num_signatures guardian signatures have been checked.

Warning

Using partially verified price updates is dangerous, as it lowers the threshold of guardians that need to collude to produce a malicious price update.

Variants



Partial

Fields

num_signatures: u8


Full