#[repr(C)]pub struct PriceFeedMessage {
pub feed_id: [u8; 32],
pub price: i64,
pub conf: u64,
pub exponent: i32,
pub publish_time: i64,
pub prev_publish_time: i64,
pub ema_price: i64,
pub ema_conf: u64,
}Fields
feed_id: [u8; 32]price: i64conf: u64exponent: i32publish_time: i64prev_publish_time: i64ema_price: i64ema_conf: u64Trait Implementations
Sourceimpl BorshDeserialize for PriceFeedMessagewhere
[u8; 32]: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
i32: BorshDeserialize,
impl BorshDeserialize for PriceFeedMessagewhere
[u8; 32]: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
i32: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for PriceFeedMessage
impl BorshSerialize for PriceFeedMessage
Sourceimpl Clone for PriceFeedMessage
impl Clone for PriceFeedMessage
Sourcefn clone(&self) -> PriceFeedMessage
fn clone(&self) -> PriceFeedMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PriceFeedMessage
impl Debug for PriceFeedMessage
Sourceimpl Default for PriceFeedMessage
impl Default for PriceFeedMessage
Sourcefn default() -> PriceFeedMessage
fn default() -> PriceFeedMessage
Returns the “default value” for a type. Read more
impl Copy for PriceFeedMessage