pub struct TimeLock {
pub owner: Pubkey,
pub payer: Pubkey,
pub release_slot: u64,
}Expand description
Time lock used to prevent an order being executed before the release_slot
Fields
owner: Pubkeypayer: Pubkeyrelease_slot: u64Trait Implementations
Sourceimpl BorshDeserialize for TimeLock
impl BorshDeserialize for TimeLock
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TimeLock
impl BorshSerialize for TimeLock
impl Copy for TimeLock