Module utils
pyra_
instructions
0.4.2
Module utils
Module Items
Enums
In pyra_
instructions::
pyra_
program
pyra_instructions
::
pyra_program
Module
utils
Program utilities.
Enums

Account
An enum that includes all accounts of the declared program as a tuple variant.
Event
An enum that includes all events of the declared program as a tuple variant.